c What follows are the codes for computing Peterson's new low and high
c noise models. The first piece of code below is a simple program
c demonstrating the use of the subroutines.
c 
c Let me know if you have any problems or questions. Send me e-mail if
c you would like a printed copy of Peterson's report.
c 
c Bob Woodward
c Data Collection Center, Albuquerque Seismolocial Laboratory, USGS 
c woodward@asl.cr.usgs.gov
c
c 5/22/97 -- corrections made to both the lnm and hnm routines. There
c was an error in the units conversion performed at the end of each
c of these subroutines. The error did not affect the calculation
c if acceleration units were chosen. 
c
c----------------------------------------------------------------------
c
c     fhigh = 10.0
c     flow = .00001
c     fpts = 1000.
c     df = (alog10(fhigh) - alog10(flow) ) / fpts
c     
c     open(8,file='noise.dat')
c     
c     do 10 i=1,fpts+1
c       f = 10.0**( alog10(flow) + float(i-1) * df )
c       p = 1.0 / f
c       call lnm(p, 'a', psddb_low)        
c       call hnm(p, 'a', psddb_hi)
c       write(8,*) p,psddb_low,psddb_hi
c10   continue
c
c     close(8)
c     stop
c     end
c
c---------------------------------------------------------------------
c
c This subroutine generates Peterson's *new* low noise model. This low
c noise model "is a composite of station spectra obtained from many
c different instruments, vaults, geologic environments, and geographic
c regions. It is a hypothetical background spectrum that is unlikely to
c be duplicated at any single location on the Earth."
c 
c The complete reference for this noise model is:
c
c  Observations and Modeling of Seismic Background Noise, Jon Peterson,
c  Open-File Report 93-322, U.S. Department of Interior, U.S. Geological
c  Survey, Albuquerque, NM, USA, 1993, 
c
c subroutine arguments are as follows
c
c input:
c
c   p    = the period in seconds (real*4)
c   resp = determines the spectral density to be returned (char*1)
c	where: 'd' = displacement, m**2/Hz
c	       'v' = velocity, m**2/s**2/Hz
c	       'a' = acceleration, m**2/s**4/Hz
c output:
c
c   psddb = the power spectral density relative to unit spectral density
c
c calls:
c
c   calls no other routines
c
c
	subroutine lnm(p,resp,psddb)
	character*1 resp
	dimension pab(3,21)
	data pi/3.141592654/, pmin/0.10/, pmax/100000.00/

	data ((pab(i,j), i=1,3), j=1,16)/
     & 0.10,     -162.36,     5.64,
     & 0.17,     -166.70,     0.00,
     & 0.40,     -170.00,    -8.30,
     & 0.80,     -166.40,    28.90,
     & 1.24,     -168.60,    52.48,
     & 2.40,     -159.98,    29.81,
     & 4.30,     -141.10,     0.00,
     & 5.00,      -71.36,   -99.77,
     & 6.00,      -97.26,   -66.49,
     & 10.00,    -132.18,   -31.57,
     & 12.00,    -205.27,    36.16,
     & 15.60,     -37.65,  -104.33,
     & 21.90,    -114.37,   -47.10,
     & 31.60,    -160.58,   -16.28,
     & 45.00,    -187.50,     0.00,
     & 70.00,    -216.47,    15.70/

	data ((pab(i,j), i=1,3), j=17,21)/
     & 101.00,   -185.00,     0.00,
     & 154.00,   -168.34,    -7.61,
     & 328.00,   -217.43,    11.90,
     & 600.00,   -258.28,    26.60,
     & 10000.00, -346.88,    48.75/
c
c check that we are in range
c
	if (p.lt.pmin .or. p.gt.pmax) then
	  write(*,*) 'ERROR - period out of range'
	  psddb = 0.0
	  return
       endif
c
c compute psddb - step down through periods until we find the right one
c       
       do 10 i=21,1,-1
	 if (p .ge. pab(1,i)) then
           psddb = pab(2,i) + pab(3,i) * alog10( p )
           goto 100
         endif
 10    continue
c
c convert units
c 
 100   if(resp.eq.'v' .or. resp.eq.'V')  
     &     psddb = psddb + 20.0 * alog10(p/(2.0*pi))
	if(resp.eq.'d' .or. resp.eq.'D')  
     &     psddb = psddb + 20.0 * alog10( (p/(2.0*pi))**2 )
	return
	end
c
c----------------------------------------------------------------------
c
c This subroutine generates Peterson's *new* high noise model. This
c model is "a spectrum of *average* high background noise power in the
c (global) network."
c
c The complete reference for this noise model is:
c
c  Observations and Modeling of Seismic Background Noise, Jon Peterson,
c  Open-File Report 93-322, U.S. Department of Interior, U.S. Geological
c  Survey, Albuquerque, NM, USA, 1993, 
c
c subroutine arguments are as follows
c
c input:
c
c   p    = the period in seconds (real*4)
c   resp = determines the spectral density to be returned (char*1)
c	where: 'd' = displacement, m**2/Hz
c	       'v' = velocity, m**2/s**2/Hz
c	       'a' = acceleration, m**2/s**4/Hz
c output:
c
c   psddb = the power spectral density relative to unit spectral density
c
c calls:
c
c   calls no other routines
c
	subroutine hnm(p,resp,psddb)
	character*1 resp
	dimension pab(3,11)
	data pi/3.141592654/, pmin/0.10/, pmax/100000.00/

	data ((pab(i,j), i=1,3), j=1,11)/
     & 0.10,      -108.73,   -17.23,
     & 0.22,      -150.34,   -80.50,
     & 0.32,      -122.31,   -23.87,
     & 0.80,      -116.85,    32.51,
     & 3.80,      -108.48,    18.08,
     & 4.60,       -74.66,   -32.95,
     & 6.30,         0.66,  -127.18,
     & 7.90,       -93.37,   -22.42,
     & 15.40,       73.54,  -162.98,
     & 20.00,     -151.52,    10.01,
     & 354.80,    -206.66,    31.63/
c
c check that we are in range
c
	if (p.lt.pmin .or. p.gt.pmax) then
	  write(*,*) 'ERROR - period out of range'
	  psddb = 0.0
	  return
       endif
c
c compute psddb - step down through periods until we find the right one
c       
       do 10 i=11,1,-1
	 if (p .ge. pab(1,i)) then
           psddb = pab(2,i) + pab(3,i) * alog10( p )
           goto 100
         endif
 10    continue
c
c convert units
c 
 100   if(resp.eq.'v' .or. resp.eq.'V')  
     &     psddb = psddb + 20.0 * alog10(p/(2.0*pi))
	if(resp.eq.'d' .or. resp.eq.'D')  
     &     psddb = psddb + 20.0 * alog10( (p/(2.0*pi))**2 )
	return
	end
************************************************************************
*
*
*      use the USGS routines to compute noise models
*         xp and yp contain the noise values as
*         a polygon of 2*npts+1 points in length
*         xp and yp must be dimensioned at least 2*npts+1
*      the reults are in MKS units, use scale to convert to other
*         units
*
*      the 0.05 is 1 / (2 * 10) the 2 from a swuare root, the 10 from
*      the documents in FDSN manual
*
************************************************************************
*
       subroutine get_usgs_noise(pmin,pmax,xp,yp,npts,mxpts,scale)
       real xp(mxpts), yp(mxpts)
       integer npts
              
       dp = (10.0**pmax - 10.0**pmin) / (npts-1)
       
       
       do 1 i = 1, npts
         p = real(i-1)*dp + 10**pmin
	 call lnm(p,'d',ytmp)
	 yp(i) = log10(scale * (sqrt(10.0**(ytmp/10.0))))
	 xp(i) = log10(p)
1      continue
*
       do 2 i = 1, npts
         k = npts + i
         p = 10**pmax - real(i-1)*dp
	 call hnm(p,'d',ytmp)
	 yp(k) = log10(scale * (sqrt(10.0**(ytmp/10.0))))
	 xp(k) = log10(p)
2      continue
*      
       yp(2*npts+1) = yp(1)
       xp(2*npts+1) = xp(1)

       return
       end
